---
title: Save
description: Represents a command for an agent to save a survivor.
---

## Signature

```py
Save()
```

## Description

Represents a command instructing the agent to save the survivor located on the top layer of its current cell.  
This command will only succeed if the top layer of the cell contains a survivor.  

## Example

```py
top_layer = cell.get_top_layer()
if isinstance(top_layer, Survivor):
  agent.send(Save)
```
